# -*- coding: utf-8 -*-
#  Copyright (C) 2006, 2007, 2008, 2010 Stewart Adam
#  This file is part of fwfstab.

#  fwfstab is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.

#  fwfstab is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
#  GNU General Public License for more details.

#  You should have received a copy of the GNU General Public License
#  along with fwfstab; if not, write to the Free Software
#  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
#  Parts taken or adapted from `hwbrowser' - Copyright 2001 Red Hat, Inc.
"""
A python library to interface with the fstab and detect disk geometry.
"""
import subprocess
import os

__author__ = "Stewart Adam <s.adam@diffingo.com>"
__status__ = "beta"
__version__ = "0.04rc1"
__license__ = "GNU GPLv2+"

def which(command):
  """Python equivalent of the 'which' executable"""
  for path in os.environ["PATH"].split(":"):
    executable_path = os.path.join(path, command)
    if os.path.exists(executable_path):
      return executable_path
  return False

def execute(command, env=None, shell=False, stdoutfd=subprocess.PIPE):
  """Execute a command, wait for it to finish"""
  sub = subprocess.Popen(command, stdin=subprocess.PIPE, stdout=stdoutfd, stderr=subprocess.PIPE, shell=shell, env=env)
  return sub.wait(), sub.stdout, sub.stderr

def executeSub(command, env=None, shell=False, stdoutfd=subprocess.PIPE):
  """Execute a command in the background"""
  sub = subprocess.Popen(command, stdin=subprocess.PIPE, stdout=stdoutfd, stderr=subprocess.PIPE, shell=shell, env=env)
  return sub

def CheckPerms(path, mustExist=False):
  """Checks for read and write permissions."""
  read = CheckPermsRead(path, mustExist)
  write = CheckPermsWrite(path, mustExist)
  if read == True and write == True:
      return True
  return False

def CheckPermsRead(path, mustExist=False):
  """Checks for read permissions."""
  if not os.path.exists(path) and not mustExist:
    path = os.path.dirname(path)
  return os.access(path, os.R_OK)

def CheckPermsWrite(path, mustExist=False):
  """Checks for write permissions."""
  if not os.path.exists(path) and not mustExist:
    path = os.path.dirname(path)
  return os.access(path, os.W_OK)
